==> mgpcli-0.1.71.tar.gz: workflow/lib/component/log/filter_appbar.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:workflow/component/widget/drop_down_menu.dart';
import 'package:workflow/provider/log_state_provider.dart';

/// 日志的表头
class FilterAppBar extends StatefulWidget {
  final List<String> menu;
  final void Function(String level) onMenuTap;
  final GestureTapCallback onClearTap;

  const FilterAppBar(this.menu, {Key key, this.onMenuTap, this.onClearTap})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _State();
  }
}

class _State extends State<FilterAppBar> {
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 60,
      color: Color.fromARGB(0xFF, 0x22, 0x22, 0x22),
      padding: const EdgeInsets.symmetric(horizontal: 10),
      child: Row(
        children: <Widget>[
          Icon(Icons.view_agenda, color: Colors.white),
          Container(width: 10),
          Text('日志', style: TextStyle(color: Colors.white)),
          Spacer(),
          DropDownMenu(
            title: '过滤',
            menuList: widget.menu,
            titleTextStyle: TextStyle(color: Colors.white),
            onSelected: widget.onMenuTap,
          ),
          Text('自动滚动', style: TextStyle(color: Colors.white)),
          Consumer<LogStateProvider>(
            builder: (ctx, provider, child) => Checkbox(
              checkColor: Colors.white,
              value: provider.needScroll,
              onChanged: (_) {
                provider.setScroll(_);
              },
            ),
          ),
          IconButton(
            icon: Icon(Icons.delete_forever, color: Colors.white),
            onPressed: widget.onClearTap,
          )
        ],
      ),
    );
  }
}

==> mgpcli-0.1.72.tar.gz: workflow/lib/component/log/filter_appbar.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:workflow/component/widget/drop_down_menu.dart';
import 'package:workflow/provider/log_state_provider.dart';

/// 日志的表头
class FilterAppBar extends StatefulWidget {
  final List<String> menu;
  final void Function(String level) onMenuTap;
  final GestureTapCallback onClearTap;

  const FilterAppBar(this.menu, {Key key, this.onMenuTap, this.onClearTap})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _State();
  }
}

class _State extends State<FilterAppBar> {
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 60,
      color: Theme.of(context).primaryColor,
      padding: const EdgeInsets.symmetric(horizontal: 10),
      child: Row(
        children: <Widget>[
          Icon(Icons.text_rotate_vertical, color: Colors.white),
          Container(width: 10),
          Text('日志', style: TextStyle(color: Colors.white)),
          Spacer(),
          DropDownMenu(
            title: '过滤',
            menuList: widget.menu,
            titleTextStyle: TextStyle(color: Colors.white),
            onSelected: widget.onMenuTap,
          ),
          Text('自动滚动', style: TextStyle(color: Colors.white)),
          Consumer<LogStateProvider>(
            builder: (ctx, provider, child) => Theme(
                data: ThemeData(
                    unselectedWidgetColor: Colors.white,
                    toggleableActiveColor: Theme.of(context).primaryColor),
                child: Checkbox(
                  checkColor: Colors.white,
                  value: provider.needScroll,
                  onChanged: (_) {
                    provider.setScroll(_);
                  },
                )),
          ),
          IconButton(
            icon: Icon(Icons.delete_forever, color: Colors.white),
            onPressed: widget.onClearTap,
          )
        ],
      ),
    );
  }
}
